==> crow-2.11.0.tar.bz2: crow-2.11.0/service/container.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2007 Maxim Udushlivy
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef CROW_CONTAINER_H
#define CROW_CONTAINER_H

#include <gtk/gtk.h>

#ifdef CROW_SANDBOX
	#define G_DISABLE_DEPRECATED
	#define GDK_DISABLE_DEPRECATED
	#define GDK_PIXBUF_DISABLE_DEPRECATED
	#define PANGO_DISABLE_DEPRECATED
	#define GTK_DISABLE_DEPRECATED
#endif

#ifdef G_LOG_DOMAIN
	#undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "CrowContainer"

#define Check(expr) if(!(expr)) CheckFailed(#expr, __FILE__, __LINE__); else

void CheckFailed(const gchar * expr, const gchar * file, unsigned line);
void FatalError(const gchar * message);

typedef struct CrowContainer CrowContainer;
typedef struct CrowContainerClass CrowContainerClass;

struct CrowContainer {
  GObject parent;
	int counter;
	GHashTable * designers;
	gchar ** defIconPath;
};

struct CrowContainerClass {
  GObjectClass parent;
	GObjectClass * parent_class;
};

#define CROW_TYPE_CONTAINER (crow_container_get_type())
#define CROW_CONTAINER(object) (G_TYPE_CHECK_INSTANCE_CAST((object), CROW_TYPE_CONTAINER, CrowContainer))
#define CROW_CONTAINER_CLASS(meta) (G_TYPE_CHECK_CLASS_CAST((meta), CROW_TYPE_CONTAINER, CrowContainerClass))
#define CROW_IS_CONTAINER(object) (G_TYPE_CHECK_INSTANCE_TYPE((object), CROW_TYPE_CONTAINER))
#define CROW_IS_CONTAINER_CLASS(meta) (G_TYPE_CHECK_CLASS_TYPE((meta), CROW_TYPE_CONTAINER))
#define CROW_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), CROW_TYPE_CONTAINER, CrowContainerClass))

GType crow_container_get_type(void);
void crow_container_class_init(CrowContainerClass * meta);
void crow_container_init(CrowContainer * obj);
void crow_container_finalize(GObject * object);

CrowContainer ** ContainerPtr(void);
CrowContainer * ContainerGet(void);
void ContainerEnter(void);
void ContainerLeave(void);
void ContainerInit(CrowContainer * obj);
void ContainerDone(CrowContainer * obj);
CrowDesigner * CreateDesigner(GdkNativeWindow handle);
void RemoveDesigner(gpointer value);
CrowDesigner * FindDesigner(CrowContainer * obj, gint id);
GHashTable * CloneSettings(GHashTable * settings);
void CloneSetting(gpointer key, gpointer value, gpointer result);
gchar ** VStrMerge(gchar ** vstr1, gchar ** vstr2);
gboolean VStrEqual(gchar ** vstr1, gchar ** vstr2);

void OnActionsUpdated(CrowDesigner * obj, CrowActions changed, CrowContainer * container);
void OnStatusUpdated(CrowDesigner * obj, const gchar * status, CrowContainer * container);
void OnInfoUpdated(CrowDesigner * obj, const gchar * info, CrowContainer * container);
void OnShowUrl(CrowDesigner * obj, const gchar * url, CrowContainer * container);
void OnModalEnter(CrowDesigner * obj, CrowContainer * container);
void OnModalLeave(CrowDesigner * obj, CrowContainer * container);

gboolean crow_container_get_version(CrowContainer * obj, gint * version, GError ** error);
gboolean crow_container_shutdown(CrowContainer * obj, GError ** error);
gboolean crow_container_create(CrowContainer * obj, gint64 handle, gint * id, GError ** error);
gboolean crow_container_remove(CrowContainer * obj, gint id, GError ** error);
gboolean crow_container_apply_settings(CrowContainer * obj, gint id, GHashTable * settings, GError ** error);
gboolean crow_container_store_settings(CrowContainer * obj, gint id, GHashTable * original, GHashTable ** settings, GError ** error);
gboolean crow_container_clear(CrowContainer * obj, gint id, GError ** error);
gboolean crow_container_load(CrowContainer * obj, gint id, const gchar * data, GError ** error);
gboolean crow_container_save(CrowContainer * obj, gint id, gchar ** data, GError ** error);
gboolean crow_container_save_header(CrowContainer * obj, gint id, gchar ** data, GError ** error);
gboolean crow_container_saved(CrowContainer * obj, gint id, GError ** error);
gboolean crow_container_get_enabled_actions(CrowContainer * obj, gint id, gint64 * actions, GError ** error);
gboolean crow_container_run_action(CrowContainer * obj, gint id, gint64 action, GError ** error);

#endif

==> crow-2.11.3.tar.bz2: crow-2.11.3/service/container.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2008 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifndef CROW_CONTAINER_H
#define CROW_CONTAINER_H

#include <gtk/gtk.h>

#ifdef CROW_SANDBOX
	#define G_DISABLE_DEPRECATED
	#define GDK_DISABLE_DEPRECATED
	#define GDK_PIXBUF_DISABLE_DEPRECATED
	#define PANGO_DISABLE_DEPRECATED
	#define GTK_DISABLE_DEPRECATED
#endif

#ifdef G_LOG_DOMAIN
	#undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "CrowContainer"

#define Check(expr) ((expr) ? NoOp() : (CheckFailed(#expr, __FILE__, __LINE__), NoOp()))

void CheckFailed(const gchar * expr, const gchar * file, unsigned line);
void FatalError(const gchar * message);
int NoOp(void);

typedef struct CrowContainer CrowContainer;
typedef struct CrowContainerClass CrowContainerClass;

struct CrowContainer {
  GObject parent;
	int counter;
	GHashTable * designers;
	gchar ** defIconPath;
};

struct CrowContainerClass {
  GObjectClass parent;
	GObjectClass * parent_class;
};

#define CROW_TYPE_CONTAINER (crow_container_get_type())
#define CROW_CONTAINER(object) (G_TYPE_CHECK_INSTANCE_CAST((object), CROW_TYPE_CONTAINER, CrowContainer))
#define CROW_CONTAINER_CLASS(meta) (G_TYPE_CHECK_CLASS_CAST((meta), CROW_TYPE_CONTAINER, CrowContainerClass))
#define CROW_IS_CONTAINER(object) (G_TYPE_CHECK_INSTANCE_TYPE((object), CROW_TYPE_CONTAINER))
#define CROW_IS_CONTAINER_CLASS(meta) (G_TYPE_CHECK_CLASS_TYPE((meta), CROW_TYPE_CONTAINER))
#define CROW_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), CROW_TYPE_CONTAINER, CrowContainerClass))

GType crow_container_get_type(void);
void crow_container_class_init(CrowContainerClass * meta);
void crow_container_init(CrowContainer * obj);
void crow_container_finalize(GObject * object);

CrowContainer ** ContainerPtr(void);
CrowContainer * ContainerGet(void);
void ContainerEnter(void);
void ContainerLeave(void);
void ContainerInit(CrowContainer * obj);
void ContainerDone(CrowContainer * obj);
CrowDesigner * CreateDesigner(GdkNativeWindow handle);
void RemoveDesigner(gpointer value);
CrowDesigner * FindDesigner(CrowContainer * obj, gint id);
GHashTable * CloneSettings(GHashTable * settings);
void CloneSetting(gpointer key, gpointer value, gpointer result);
gchar ** VStrMerge(gchar ** vstr1, gchar ** vstr2);
gboolean VStrEqual(gchar ** vstr1, gchar ** vstr2);

void OnActionsUpdated(CrowDesigner * obj, CrowActions changed, CrowContainer * container);
void OnStatusUpdated(CrowDesigner * obj, const gchar * status, CrowContainer * container);
void OnInfoUpdated(CrowDesigner * obj, const gchar * info, CrowContainer * container);
void OnShowUrl(CrowDesigner * obj, const gchar * url, CrowContainer * container);
void OnModalEnter(CrowDesigner * obj, CrowContainer * container);
void OnModalLeave(CrowDesigner * obj, CrowContainer * container);

gboolean crow_container_get_version(CrowContainer * obj, gint * version, GError ** error);
gboolean crow_container_shutdown(CrowContainer * obj, GError ** error);
gboolean crow_container_create(CrowContainer * obj, gint64 handle, gint * id, GError ** error);
gboolean crow_container_remove(CrowContainer * obj, gint id, GError ** error);
gboolean crow_container_apply_settings(CrowContainer * obj, gint id, GHashTable * settings, GError ** error);
gboolean crow_container_store_settings(CrowContainer * obj, gint id, GHashTable * original, GHashTable ** settings, GError ** error);
gboolean crow_container_clear(CrowContainer * obj, gint id, GError ** error);
gboolean crow_container_load(CrowContainer * obj, gint id, const gchar * data, GError ** error);
gboolean crow_container_save(CrowContainer * obj, gint id, gchar ** data, GError ** error);
gboolean crow_container_save_header(CrowContainer * obj, gint id, gchar ** data, GError ** error);
gboolean crow_container_saved(CrowContainer * obj, gint id, GError ** error);
gboolean crow_container_get_enabled_actions(CrowContainer * obj, gint id, gint64 * actions, GError ** error);
gboolean crow_container_run_action(CrowContainer * obj, gint id, gint64 action, GError ** error);

#endif
